@@ -1,7 +1,6 @@
 from gi.repository import Gtk
-from passwordsafe.scrolled_page import ScrolledPage
 from gettext import gettext as _
-from threading import Timer
+from passwordsafe.notes_dialog import NotesDialog
 import passwordsafe.passphrase_generator
 import passwordsafe.password_generator
 import passwordsafe.config_manager
@@ -27,18 +26,19 @@ class EntryPage:
 
     # Entry creation/editing page headerbar
     def set_entry_page_headerbar(self):
-        mod_box = self.unlocked_database.builder.get_object("mod_box")
+        self.unlocked_database.builder.get_object("linkedbox_right").hide()
 
-        for child in mod_box.get_children():
-            mod_box.remove(child)
+        filename_label = self.unlocked_database.builder.get_object("filename_label")
+        filename_label.set_text(self.unlocked_database.database_manager.get_entry_name_from_entry_object(self.unlocked_database.current_group))
 
-        mod_box.show_all()
-        self.unlocked_database.builder.get_object("linked_box1").show_all()
+        secondary_menupopover_button = self.unlocked_database.builder.get_object("secondary_menupopover_button")
+        secondary_menupopover_button.show_all()
 
-        entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
-        scrolled_page = self.unlocked_database.stack.get_child_by_name(entry_uuid)
+        duplicate_menu_entry = self.unlocked_database.builder.get_object("duplicate_menu_entry")
+        duplicate_menu_entry.show_all()
 
-        self.unlocked_database.builder.get_object("linked_box1").hide()
+        references_menu_entry = self.unlocked_database.builder.get_object("references_menu_entry")
+        references_menu_entry.show_all()
 
         self.unlocked_database.responsive_ui.headerbar_back_button()
         self.unlocked_database.responsive_ui.headerbar_selection_button()
@@ -69,6 +69,7 @@ class EntryPage:
 
                 scrolled_page.name_property_value_entry.connect("changed", self.on_property_value_entry_changed, "name")
                 properties_list_box.add(scrolled_page.name_property_row)
+                scrolled_page.name_property_value_entry.grab_focus()
             elif scrolled_page.name_property_row is not "":
                 value = self.unlocked_database.database_manager.get_entry_name_from_entry_uuid(entry_uuid)
                 if self.unlocked_database.database_manager.has_entry_name(entry_uuid) is True:
@@ -119,16 +120,17 @@ class EntryPage:
                 scrolled_page.generate_password_button.set_popover(builder.get_object("generate_password_popover"))
                 builder.get_object("generate_button").connect("clicked", self.on_generate_button_clicked, builder, scrolled_page.password_property_value_entry)
                 scrolled_page.password_property_value_entry.connect("icon-press", self.unlocked_database.on_copy_secondary_button_clicked)
-                scrolled_page.password_property_value_entry.connect("copy-clipboard", self.on_password_entry_copy_clipboard, None)
+                scrolled_page.password_property_value_entry.connect("copy-clipboard", self.unlocked_database.on_copy_secondary_button_clicked, None, None)
                 self.unlocked_database.bind_accelerator(self.unlocked_database.accelerators, scrolled_page.password_property_value_entry, "<Control><Shift>c", signal="copy-clipboard")
                 scrolled_page.password_property_value_entry.connect("changed", self.on_property_value_entry_changed, "password")
 
                 scrolled_page.password_level_bar = builder.get_object("password_level_bar")
                 scrolled_page.password_level_bar.add_offset_value("weak", 1.0)
                 scrolled_page.password_level_bar.add_offset_value("medium", 3.0)
-                scrolled_page.password_level_bar.add_offset_value("strong", 5.0)
-                scrolled_page.password_level_bar.add_offset_value("secure", 6.0)
-                scrolled_page.password_level_bar.set_value(float(passwordsafe.password_generator.strength(scrolled_page.password_property_value_entry.get_text())))
+                scrolled_page.password_level_bar.add_offset_value("strong", 4.0)
+                scrolled_page.password_level_bar.add_offset_value("secure", 5.0)
+
+                self.set_password_level_bar(scrolled_page)
 
                 self.change_password_entry_visibility(scrolled_page.password_property_value_entry, scrolled_page.show_password_button)
 
@@ -172,6 +174,9 @@ class EntryPage:
             if scrolled_page.notes_property_row is NotImplemented:
                 scrolled_page.notes_property_row = builder.get_object("notes_property_row")
                 scrolled_page.notes_property_value_entry = builder.get_object("notes_property_value_entry")
+
+                builder.get_object("notes_detach_button").connect("clicked", self.on_notes_detach_button_clicked)
+
                 buffer = scrolled_page.notes_property_value_entry.get_buffer()
                 value = self.unlocked_database.database_manager.get_entry_notes_from_entry_uuid(entry_uuid)
                 if self.unlocked_database.database_manager.has_entry_notes(entry_uuid) is True:
@@ -202,13 +207,13 @@ class EntryPage:
                 scrolled_page.purple_button = builder.get_object("purple_button")
                 scrolled_page.brown_button = builder.get_object("brown_button")
 
-                scrolled_page.none_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.orange_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.green_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.blue_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.red_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.purple_button.connect("toggled", self.on_entry_color_button_toggled)
-                scrolled_page.brown_button.connect("toggled", self.on_entry_color_button_toggled)
+                scrolled_page.none_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.orange_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.green_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.blue_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.red_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.purple_button.connect("clicked", self.on_entry_color_button_toggled)
+                scrolled_page.brown_button.connect("clicked", self.on_entry_color_button_toggled)
 
                 scrolled_page.none_button.get_children()[0].hide()
                 scrolled_page.orange_button.get_children()[0].hide()
@@ -329,7 +334,6 @@ class EntryPage:
             properties_list_box.add(scrolled_page.show_all_row)
 
     def add_attribute_property_row(self, key, value):
-        entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
         scrolled_page = self.unlocked_database.stack.get_child_by_name(self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group))
 
         builder = Gtk.Builder()
@@ -345,7 +349,7 @@ class EntryPage:
 
         attribute_property_row.set_name(key)
         attribute_property_name_label.set_text(key)
-        if value != None:
+        if value is not None:
             attribute_value_entry.set_text(value)
         attribute_value_entry.connect("changed", self.on_attributes_value_entry_changed)
         attribute_remove_button.connect("clicked", self.on_attribute_remove_button_clicked)
@@ -386,79 +390,38 @@ class EntryPage:
             self.unlocked_database.database_manager.set_entry_username(entry_uuid, widget.get_text())
         elif type == "password":
             self.unlocked_database.database_manager.set_entry_password(entry_uuid, widget.get_text())
-            scrolled_page.password_level_bar.set_value(float(passwordsafe.password_generator.strength(widget.get_text())))
+            self.set_password_level_bar(scrolled_page)
         elif type == "url":
             self.unlocked_database.database_manager.set_entry_url(entry_uuid, widget.get_text())
         elif type == "notes":
             self.unlocked_database.database_manager.set_entry_notes(entry_uuid, widget.get_text(widget.get_start_iter(), widget.get_end_iter(), False))
 
+    def on_notes_detach_button_clicked(self, button):
+        self.unlocked_database.start_database_lock_timer()
+        NotesDialog(self.unlocked_database)
+
     def on_entry_icon_button_toggled(self, button):
+        if button.get_active() is False:
+            return
+
         self.unlocked_database.start_database_lock_timer()
         entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
-
-        old_icon = str(self.unlocked_database.database_manager.get_entry_icon_from_entry_uuid(entry_uuid))
-
         scrolled_page = self.unlocked_database.stack.get_child_by_name(self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group))
 
-        if old_icon != button.get_name():
-            if old_icon == "19":
-                scrolled_page.mail_icon_button.set_active(False)
-            if old_icon == "9":
-                scrolled_page.profile_icon_button.set_active(False)
-            if old_icon == "1":
-                scrolled_page.network_profile_button.set_active(False)
-            if old_icon == "0":
-                scrolled_page.key_button.set_active(False)
-            if old_icon == "30":
-                scrolled_page.terminal_icon_button.set_active(False)
-            if old_icon == "34":
-                scrolled_page.setting_icon_button.set_active(False)
-            if old_icon == "48":
-                scrolled_page.folder_icon_button.set_active(False)
-            if old_icon == "27":
-                scrolled_page.harddrive_icon_button.set_active(False)
-            if old_icon == "12":
-                scrolled_page.wifi_icon_button.set_active(False)
-            if old_icon == "23":
-                scrolled_page.desktop_icon_button.set_active(False)
-            scrolled_page.set_made_database_changes(True)
-            self.unlocked_database.database_manager.set_entry_icon(entry_uuid, button.get_name())
+        if str(self.unlocked_database.database_manager.get_entry_icon_from_entry_uuid(entry_uuid)) == button.get_name():
+            return
+
+        scrolled_page.set_made_database_changes(True)
+        self.unlocked_database.database_manager.set_entry_icon(entry_uuid, button.get_name())
 
     def on_entry_color_button_toggled(self, button):
+        if button.get_active() is False:
+            return
+
         self.unlocked_database.start_database_lock_timer()
         entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
-
         scrolled_page = self.unlocked_database.stack.get_child_by_name(self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group))
 
-        old_color = self.unlocked_database.database_manager.get_entry_color_from_entry_uuid(entry_uuid)
-
-        if old_color != button.get_name():
-            if old_color == "NoneColorButton":
-                scrolled_page.none_button.set_active(False)
-                scrolled_page.none_button.get_children()[0].hide()
-            if old_color == "BlueColorButton":
-                scrolled_page.blue_button.set_active(False)
-                scrolled_page.blue_button.get_children()[0].hide()
-            if old_color == "GreenColorButton":
-                scrolled_page.green_button.set_active(False)
-                scrolled_page.green_button.get_children()[0].hide()
-            if old_color == "OrangeColorButton":
-                scrolled_page.orange_button.set_active(False)
-                scrolled_page.orange_button.get_children()[0].hide()
-            if old_color == "RedColorButton":
-                scrolled_page.red_button.set_active(False)
-                scrolled_page.red_button.get_children()[0].hide()
-            if old_color == "PurpleColorButton":
-                scrolled_page.purple_button.set_active(False)
-                scrolled_page.purple_button.get_children()[0].hide()
-            if old_color == "BrownColorButton":
-                scrolled_page.brown_button.set_active(False)
-                scrolled_page.brown_button.get_children()[0].hide()
-            scrolled_page.set_made_database_changes(True)
-            self.unlocked_database.database_manager.set_entry_color(entry_uuid, button.get_name())
-
-        button.get_children()[0].show_all()
-
         if button.get_name() != "NoneColorButton":
             image = button.get_children()[0]
             image.set_name("BrightIcon")
@@ -466,19 +429,15 @@ class EntryPage:
             image = button.get_children()[0]
             image.set_name("DarkIcon")
 
-        if button.get_active() is False:
-            button.get_children()[0].hide()
+        if self.unlocked_database.database_manager.get_entry_color_from_entry_uuid(entry_uuid) == button.get_name():
+            return
 
-    def on_password_entry_copy_clipboard(self, widget, test):
-        self.unlocked_database.start_database_lock_timer()
-        if self.unlocked_database.clipboard_timer is not NotImplemented:
-            self.unlocked_database.clipboard_timer.cancel()
+        for btn in button.get_parent().get_children():
+            btn.get_children()[0].hide()
 
-        self.unlocked_database.clipboard.set_text(widget.get_text(), -1)
-        self.unlocked_database.show_database_action_revealer(_("Copied to clipboard"))
-        clear_clipboard_time = passwordsafe.config_manager.get_clear_clipboard()
-        self.unlocked_database.clipboard_timer = Timer(clear_clipboard_time, self.unlocked_database.clear_clipboard)
-        self.unlocked_database.clipboard_timer.start()
+        button.get_children()[0].show_all()
+        scrolled_page.set_made_database_changes(True)
+        self.unlocked_database.database_manager.set_entry_color(entry_uuid, button.get_name())
 
     def on_link_secondary_button_clicked(self, widget, position, eventbutton):
         self.unlocked_database.start_database_lock_timer()
@@ -553,7 +512,6 @@ class EntryPage:
 
     def on_attributes_value_entry_changed(self, widget):
         entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
-        scrolled_page = self.unlocked_database.stack.get_child_by_name(self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group))
 
         parent = widget.get_parent().get_parent().get_parent()
         key = parent.get_name()
@@ -562,7 +520,6 @@ class EntryPage:
 
     def on_attribute_key_edit_button_clicked(self, button):
         entry_uuid = self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group)
-        scrolled_page = self.unlocked_database.stack.get_child_by_name(self.unlocked_database.database_manager.get_entry_uuid_from_entry_object(self.unlocked_database.current_group))
 
         parent = button.get_parent().get_parent().get_parent()
         key = parent.get_name()
@@ -621,3 +578,17 @@ class EntryPage:
             toggle_button.toggled()
             entry.set_visibility(True)
 
+    def set_password_level_bar(self, scrolled_page):
+        password = NotImplemented
+
+        if scrolled_page.password_property_value_entry.get_text().startswith("{REF:P"):
+            try:
+                password = self.unlocked_database.database_manager.get_entry_password_from_entry_uuid(self.unlocked_database.hex_to_base64(self.unlocked_database.reference_to_hex_uuid(scrolled_page.password_property_value_entry.get_text())))
+            except(Exception):
+                password = scrolled_page.password_property_value_entry.get_text()
+        else:
+            password = scrolled_page.password_property_value_entry.get_text()
+
+        if password is not NotImplemented:
+            scrolled_page.password_level_bar.set_value(float(passwordsafe.password_generator.strength(password)))
+
