@@ -239,7 +239,7 @@ class UnlockDatabase:
                     password_unlock_entry.grab_focus()
                     password_unlock_entry.get_style_context().add_class("error")
                     self.clear_input_fields()
-                    self.window.logging_manager.log_debug("Could not open database, wrong password")
+                    self.window.logging_manager.debug("Could not open database, wrong password")
             else:
                 password_unlock_button = self.builder.get_object("password_unlock_button")
                 password_unlock_button_image = password_unlock_button.get_children()[0]
@@ -273,7 +273,7 @@ class UnlockDatabase:
 
         self.password_only = NotImplemented
         self.set_last_used_unlock_method("password")
-        self.window.logging_manager.log_debug("Opening of database was successfull")
+        self.window.logging_manager.debug("Opening of database was successfull")
         self.open_database_page()
 
     def password_unlock_failure(self):
@@ -290,7 +290,7 @@ class UnlockDatabase:
         password_unlock_entry.grab_focus()
         password_unlock_entry.get_style_context().add_class("error")
         self.clear_input_fields()
-        self.window.logging_manager.log_debug("Could not open database, wrong password")
+        self.window.logging_manager.debug("Could not open database, wrong password")
 
     # Keyfile Unlock
 
@@ -308,7 +308,7 @@ class UnlockDatabase:
 
         response = keyfile_chooser_dialog.run()
         if response == Gtk.ResponseType.ACCEPT:
-            self.window.logging_manager.log_debug("File selected: " + keyfile_chooser_dialog.get_filename())
+            self.window.logging_manager.debug("File selected: " + keyfile_chooser_dialog.get_filename())
 
             keyfile_unlock_select_button = self.builder.get_object("keyfile_unlock_select_button")
             keyfile_unlock_select_button.get_style_context().remove_class(Gtk.STYLE_CLASS_DESTRUCTIVE_ACTION)
@@ -318,7 +318,7 @@ class UnlockDatabase:
             self.keyfile_path = keyfile_chooser_dialog.get_filename()
 
         elif response == Gtk.ResponseType.CANCEL:
-            self.window.logging_manager.log_debug("File selection canceled")
+            self.window.logging_manager.debug("File selection canceled")
 
     def on_keyfile_unlock_button_clicked(self, widget):
         keyfile_unlock_select_button = self.builder.get_object("keyfile_unlock_select_button")
@@ -351,7 +351,7 @@ class UnlockDatabase:
                 keyfile_unlock_select_button.get_style_context().add_class(Gtk.STYLE_CLASS_DESTRUCTIVE_ACTION)
                 keyfile_unlock_select_button.set_label(_("Try again"))
 
-                self.window.logging_manager.log_debug("Invalid keyfile chosen")
+                self.window.logging_manager.debug("Invalid keyfile chosen")
         elif self.keyfile_path is not NotImplemented:
             keyfile_unlock_select_button = self.builder.get_object("keyfile_unlock_select_button")
             keyfile_unlock_button = self.builder.get_object("keyfile_unlock_button")
@@ -386,7 +386,7 @@ class UnlockDatabase:
             return
 
         self.set_last_used_unlock_method("keyfile")
-        self.window.logging_manager.log_debug("Database successfully opened with keyfile")
+        self.window.logging_manager.debug("Database successfully opened with keyfile")
         self.keyfile_path = NotImplemented
         self.open_database_page()
 
@@ -408,7 +408,7 @@ class UnlockDatabase:
         keyfile_unlock_select_button.get_style_context().add_class(Gtk.STYLE_CLASS_DESTRUCTIVE_ACTION)
         keyfile_unlock_select_button.set_label(_("Try again"))
 
-        self.window.logging_manager.log_debug("Invalid keyfile chosen")
+        self.window.logging_manager.debug("Invalid keyfile chosen")
 
     # Composite Unlock
 
@@ -430,7 +430,7 @@ class UnlockDatabase:
 
         response = filechooser_opening_dialog.run()
         if response == Gtk.ResponseType.ACCEPT:
-            self.window.logging_manager.log_debug("File selected: " + filechooser_opening_dialog.get_filename())
+            self.window.logging_manager.debug("File selected: " + filechooser_opening_dialog.get_filename())
             file_path = filechooser_opening_dialog.get_filename()
 
             label = Gtk.Label()
@@ -442,7 +442,7 @@ class UnlockDatabase:
 
             self.composite_keyfile_path = file_path
         elif response == Gtk.ResponseType.CANCEL:
-            self.window.logging_manager.log_debug("File selection cancelled")
+            self.window.logging_manager.debug("File selection cancelled")
 
     def on_composite_unlock_button_clicked(self, widget):
         composite_unlock_entry = self.builder.get_object("composite_unlock_entry")
@@ -478,7 +478,7 @@ class UnlockDatabase:
                 composite_unlock_select_button.get_style_context().add_class("destructive-action")
                 self.clear_input_fields()
 
-                self.window.logging_manager.log_debug("Could not open database, wrong password")
+                self.window.logging_manager.debug("Could not open database, wrong password")
         else:
             if composite_unlock_entry.get_text() is not "" and self.composite_keyfile_path is not NotImplemented:
                 composite_unlock_select_button = self.builder.get_object("composite_unlock_select_button")
@@ -537,7 +537,7 @@ class UnlockDatabase:
             passwordsafe.config_manager.set_last_used_composite_key(pair_array)
 
         self.set_last_used_unlock_method("composite")
-        self.window.logging_manager.log_debug("Opening of database was successfull")
+        self.window.logging_manager.debug("Opening of database was successfull")
         self.composite_keyfile_path = NotImplemented
         self.open_database_page()
 
@@ -563,7 +563,7 @@ class UnlockDatabase:
         composite_unlock_select_button.get_style_context().add_class("destructive-action")
         self.clear_input_fields()
 
-        self.window.logging_manager.log_debug("Could not open database, wrong password")
+        self.window.logging_manager.debug("Could not open database, wrong password")
 
     #
     # Open Database
@@ -627,4 +627,3 @@ class UnlockDatabase:
     def set_last_used_unlock_method(self, method):
         if passwordsafe.config_manager.get_remember_unlock_method() is True:
             passwordsafe.config_manager.set_unlock_method(method)
-
